pub fn tool_call_presentation(call: &ToolCall) -> ToolCallPresentationExpand description
Compute the stable presentation metadata for one complete ACP call.
pub fn tool_call_presentation(call: &ToolCall) -> ToolCallPresentationCompute the stable presentation metadata for one complete ACP call.