pub fn tool_call_update_changes_presentation(
call: &ToolCall,
fields: &ToolCallUpdateFields,
) -> boolExpand description
Whether a partial update changes inputs used to derive the tool summary.
pub fn tool_call_update_changes_presentation(
call: &ToolCall,
fields: &ToolCallUpdateFields,
) -> boolWhether a partial update changes inputs used to derive the tool summary.